#!/bin/bash -eE
# (c) 2019 Mellanox Technologies
# Author: Yurii Shestakov
#------------------------------------------------------------------------
MLX_DEV=$1
logger -p local0.notice -t nvme_snap "$0: $1"
# compatability with old configuration
# when we have no systemd unit template: nvme_snap@.service
if [ -z "$MLX_DEV" ] ; then
    echo -e "Usage: $0 mlx5_n\nwhere mlx5_n is RDMA intrface name" >&2
    exit 1
fi

# Now read the env varibles
# 1st - most specific - /etc/default/nvme_snap.$MLX_DEV
# 2nd - generic - /etc/default/nvme_snap  if the above doesn't exists
#
env_fn=/etc/default/nvme_snap
if [ -e "/etc/default/nvme_snap.$MLX_DEV" ] ; then
    env_fn="/etc/default/nvme_snap.$MLX_DEV"
fi
logger -p local0.notice -t nvme_snap "$MLX_DEV: env_fn: $env_fn"
if [ -e "$env_fn" ] ; then
    source "$env_fn"
fi
# no NVME_CONFIG specified?
# use default one - /etc/nvme_snap/$MLX_DEV.json
if [ -z "$NVME_CONFIG" ] ; then
    export NVME_CONFIG="/etc/nvme_snap/$MLX_DEV.json"
fi
logger -p local0.notice -t nvme_snap "$MLX_DEV: NVME_CONFIG: $NVME_CONFIG"
if [ ! -e "$NVME_CONFIG" ] ; then
    logger -p local0.notice -t nvme_snap "$MLX_DEV: $NVME_CONFIG doesn't exist. Switch to dummy"
    export NVME_CONFIG="/etc/nvme_snap/dummy-$MLX_DEV.json"
    export NVME_DISK_SIZE_MB=64
    pfn=${MLX_DEV#mlx5_}
    d=$(ls -d /sys/class/net/*/device/infiniband/$MLX_DEV)
    p=${d%/device*}
    my_iface=${p#*/net/}
    my_ipaddr=$(ip a l $my_iface |awk '$1 == "inet" {print $2}')
    if [ -z "$my_ipaddr" ]; then
       ip addr add 127.$pfn.0.1/24 dev $my_iface
       ip link set up $my_iface
    fi
fi
if [ -n "$NVME_SNAP_LOGFILE_PATH" ] ; then
  logger -p local0.notice -t nvme_snap "$MLX_DEV: NVME_SNAP_LOGFILE_PATH: $NVME_SNAP_LOGFILE_PATH"
fi

if ! /usr/sbin/mlx_device_emulation $MLX_DEV ; then
    echo "$MLX_DEV is not emulation manager. Nothing to do..." >&2
    exit 1
fi

exec /usr/bin/nvme_controller_emu $MLX_DEV
